@@ -44,7 +44,7 @@ pub fn graph(
             }
             {
                 options.prec = options.graph_prec;
-                let split = s.split(|c| c == ';');
+                let split = s.split(';');
                 let count = split.clone().count();
                 if count != 1
                 {
@@ -98,6 +98,7 @@ pub fn graph(
                     Vec::new(),
                     true,
                     &mut Vec::new(),
+                    None,
                 )
                 {
                     Ok(f) => (f.0, f.1, options, f.2),
