@@ -45,6 +45,10 @@ FLAGS: --help (this message)\x1b[G\n\
 --siunits toggles keeping stuff in si units, a newton will show as 'm s^-2 kg' instead of 'N'\x1b[G\n\
 --keepzeros dont remove trailing zeros\x1b[G\n\n\
 - flags can be executed in runtime just without the dashes\x1b[G\n\
+- '~' will find the var value which makes the left side and right side equal each other, via newtons method starting at 0\x1b[G\n\
+- '~~' will find the var value which makes the left side and right side equal each other, via newtons method starting at -2/0/2\x1b[G\n\
+- any function with ' appeneded to the name will be converted like f'(x) goes to slope(t,f(t),x)\x1b[G\n\
+- any function with ` appeneded to the name will be converted like f`(x) goes to area(t,f(t),0,x)\x1b[G\n\
 - \"colors=\" to see color settings\x1b[G\n\
 - \"exit\" to exit the program\x1b[G\n\
 - \"clear\" to clear the screen\x1b[G\n\
@@ -116,12 +120,12 @@ Functions:\x1b[G\n\
 - An(n,k), Ap(n,t) eulerian numbers and polynomials\x1b[G\n\
 - lim(x,f(x),point (,side)) both sides are checked by default, -1 for left, 1 for right\x1b[G\n\
 - slope(x,f(x),point (,nth derivitive) (,0) ), can add a 0 to the args to not combine the x and y slopes for parametric equations, same for area\x1b[G\n\
-- area(x,f(x),from,to (,0) ), length(x,f(x),from,to), surfacearea(a,b,z(a,b),startb,endb,starta,enda)\x1b[G\n\
+- area(x,f(x),from,to(,nth)(,0) ), length(x,f(x),from,to), surfacearea(a,b,z(a,b),startb,endb,starta,enda)\x1b[G\n\
 - solve(x,f(x) (,point)) employs newtons method to find the root of a function at a starting point, assumes 0 if no point given, outputs Nan if newton method fails\x1b[G\n\
 - extrema(x,f(x) (,point)) employs newtons method to find the extrema of a function at a starting point, assumes 0 if no point given, outputs Nan if newton method fails, outputs {{x,y,positive/negitive concavity}}\x1b[G\n\
 - iter(x,f(x),p,n), f(x) iterated n times at point p, add \",1\" to args to show steps\x1b[G\n\n\
 Vector operations/functions:\x1b[G\n\
-- dot({{vec1}},{{vec2}}), cross({{vec1}},{{vec2}}), proj/project({{vec1}},{{vec2}})\x1b[G\n\
+- dot({{vec1}},{{vec2}}), cross({{vec1}},{{vec2}}), proj/project({{vec1}},{{vec2}}), oproj/oproject({{vec1}},{{vec2}})\x1b[G\n\
 - angle({{vec1}},{{vec2}})\x1b[G\n\
 - norm, normalize\x1b[G\n\
 - abs, len, any, all\x1b[G\n\
@@ -191,6 +195,7 @@ fn all_units() -> &'static str
 \"s\" | \"second\"\x1b[G\n\
 \"A\" | \"ampere\"\x1b[G\n\
 \"K\" | \"kelvin\"\x1b[G\n\
+\"u\" | \"unit\"\x1b[G\n\
 \"mol\" | \"mole\"\x1b[G\n\
 \"cd\" | \"candela\"\x1b[G\n\
 \"g\" | \"gram\"\x1b[G\n\
@@ -222,7 +227,7 @@ fn all_units() -> &'static str
 \"Ω\" | \"ohm\"\x1b[G\n\
 \"min\" | \"minute\"\x1b[G\n\
 \"h\" | \"hour\"\x1b[G\n\
-\"d\" | \"day\"\x1b[G\n\
+\"day\"\x1b[G\n\
 \"week\"\x1b[G\n\
 \"N\" | \"newton\"\x1b[G\n\
 \"C\" | \"coulomb\"\x1b[G\n\
@@ -238,7 +243,7 @@ fn all_units() -> &'static str
 \"gray\" | \"Gy\"\x1b[G\n\
 \"sievert\" | \"Sv\"\x1b[G\n\
 \"katal\" | \"kat\"\x1b[G\n\
-\"bit\" | \"b\"\x1b[G\n\
+\"bit\"\x1b[G\n\
 \"steradian\" | \"sr\"\x1b[G\n\
 \"atm\"\x1b[G\n\
 \"psi\"\x1b[G\n\
