@@ -15,7 +15,7 @@ mod units;
 //lib, gui
 use crate::{
     complex::NumStr,
-    functions::functions_with_args,
+    functions::{functions_with_args, options_list, units_list},
     graph::graph,
     help::help_for,
     load_vars::{add_var, get_cli_vars, get_file_vars, get_vars, set_commands_or_vars},
@@ -63,6 +63,7 @@ pub struct Units
     angle: f64,
     byte: f64,
     usd: f64,
+    unit: f64,
 }
 #[derive(Clone, PartialEq)]
 pub struct Number
@@ -358,6 +359,7 @@ fn main()
     {
         Vec::new()
     };
+    let mut err = false;
     let base = options.base;
     if !options.interactive && options.allow_vars && !options.stay_interactive
     {
@@ -422,7 +424,9 @@ fn main()
                                 {
                                     if l.contains('(')
                                     {
-                                        b = word == left && matches!(c, '(' | '{' | '[' | '|');
+                                        b = word.trim_end_matches('\'').trim_end_matches('`')
+                                            == left
+                                            && matches!(c, '(' | '{' | '[' | '|');
                                     }
                                     else
                                     {
@@ -459,13 +463,15 @@ fn main()
                                         if let Err(s) =
                                             add_var(le, r, i, &mut vars, options, true, true, true)
                                         {
-                                            println!("{}", s)
+                                            err = true;
+                                            println!("\x1b[G\x1b[K{}", s)
                                         }
                                     }
                                     else if let Err(s) =
                                         add_var(le, r, i, &mut vars, options, true, true, false)
                                     {
-                                        println!("{}", s)
+                                        err = true;
+                                        println!("\x1b[G\x1b[K{}", s)
                                     }
                                     continue 'upper;
                                 }
@@ -477,7 +483,8 @@ fn main()
                                     if let Err(s) =
                                         add_var(le, r, i, &mut vars, options, false, false, false)
                                     {
-                                        println!("{}", s)
+                                        err = true;
+                                        println!("\x1b[G\x1b[K{}", s)
                                     }
                                     continue 'upper;
                                 }
@@ -485,7 +492,8 @@ fn main()
                             if let Err(s) =
                                 add_var(le, r, 0, &mut vars, options, false, false, false)
                             {
-                                println!("{}", s)
+                                err = true;
+                                println!("\x1b[G\x1b[K{}", s)
                             }
                         }
                     }
@@ -493,6 +501,22 @@ fn main()
             }
         }
     }
+    if options.interactive && err
+    {
+        print!(
+            "\x1b[G\x1b[K{}{}",
+            prompt(options, &colors),
+            if options.color == Auto::True
+            {
+                "\x1b[0m"
+            }
+            else
+            {
+                ""
+            }
+        );
+        stdout.flush().unwrap();
+    }
     options.base = base;
     let (mut file, mut unmod_lines) = if options.interactive || options.stay_interactive
     {
@@ -609,6 +633,7 @@ fn main()
                     Vec::new(),
                     false,
                     &mut Vec::new(),
+                    None,
                 )
                 {
                     Ok(f) => f,
@@ -718,7 +743,7 @@ fn main()
                         }
                         if c == '\x09'
                         {
-                            clear(&input, start, end, options, &colors);
+                            clear(&input, &vars, start, end, options, &colors);
                         }
                         else
                         {
@@ -846,6 +871,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -855,7 +881,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if options.debug
                         {
@@ -873,7 +899,7 @@ fn main()
                         if input.is_empty()
                         {
                             slow = false;
-                            clear(&input, start, end, options, &colors);
+                            clear(&input, &vars, start, end, options, &colors);
                         }
                     }
                     '\x08' =>
@@ -926,6 +952,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -935,7 +962,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if options.debug
                         {
@@ -953,7 +980,7 @@ fn main()
                         if input.is_empty()
                         {
                             slow = false;
-                            clear(&input, start, end, options, &colors);
+                            clear(&input, &vars, start, end, options, &colors);
                         }
                     }
                     '\x7F' =>
@@ -1009,6 +1036,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1018,7 +1046,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if options.debug
                         {
@@ -1036,7 +1064,7 @@ fn main()
                         if input.is_empty()
                         {
                             slow = false;
-                            clear(&input, start, end, options, &colors);
+                            clear(&input, &vars, start, end, options, &colors);
                         }
                     }
                     '\x11' =>
@@ -1054,7 +1082,7 @@ fn main()
                             input.len()
                                 - (get_terminal_dimensions().0 - if options.prompt { 3 } else { 1 })
                         };
-                        clearln(&input, start, end, options, &colors);
+                        clearln(&input, &vars, start, end, options, &colors);
                     }
                     '\x18' =>
                     {
@@ -1086,6 +1114,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1095,7 +1124,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if end - placement != 0
                         {
@@ -1131,6 +1160,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1140,7 +1170,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if end - placement != 0
                         {
@@ -1178,6 +1208,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1187,7 +1218,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if end - placement != 0
                         {
@@ -1225,6 +1256,7 @@ fn main()
                                 firstslow = false;
                                 handle_err(
                                     "too slow, will print on enter",
+                                    &vars,
                                     &input,
                                     options,
                                     &colors,
@@ -1234,7 +1266,7 @@ fn main()
                             }
                             else
                             {
-                                clearln(&input, start, end, options, &colors);
+                                clearln(&input, &vars, start, end, options, &colors);
                             }
                             if end - placement != 0
                             {
@@ -1269,6 +1301,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1278,7 +1311,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if end - placement != 0
                         {
@@ -1299,7 +1332,7 @@ fn main()
                         {
                             get_terminal_dimensions().0 - if options.prompt { 3 } else { 1 }
                         };
-                        clearln(&input, start, end, options, &colors);
+                        clearln(&input, &vars, start, end, options, &colors);
                         if end - placement != 0
                         {
                             print!("\x1b[{}D", end - placement)
@@ -1336,6 +1369,7 @@ fn main()
                             };
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1378,7 +1412,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                     }
                     '\x1E' | '\x04' =>
@@ -1415,6 +1449,7 @@ fn main()
                             };
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1457,7 +1492,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                     }
                     '\x1B' =>
@@ -1473,7 +1508,7 @@ fn main()
                             {
                                 end = input.len()
                             }
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                             print!("\x1b[{}D", end - placement)
                         }
                         else if placement != 0
@@ -1496,7 +1531,7 @@ fn main()
                             start += 1;
                             placement += 1;
                             end += 1;
-                            clearln(&input, start, end, options, &colors)
+                            clearln(&input, &vars, start, end, options, &colors)
                         }
                         else if placement != input.len()
                         {
@@ -1541,7 +1576,7 @@ fn main()
                                     end = input.len()
                                 }
                                 start = placement;
-                                clearln(&input, start, end, options, &colors);
+                                clearln(&input, &vars, start, end, options, &colors);
                                 if end - placement != 0
                                 {
                                     print!("\x1b[{}D", end - placement)
@@ -1592,7 +1627,7 @@ fn main()
                                         - if options.prompt { 3 } else { 1 },
                                 );
                                 end = placement;
-                                clearln(&input, start, end, options, &colors)
+                                clearln(&input, &vars, start, end, options, &colors)
                             }
                             else if placement == s
                             {
@@ -1623,34 +1658,65 @@ fn main()
                         }
                         if !word.is_empty()
                         {
-                            let mut bank1 = Vec::new();
+                            let mut bank = Vec::new();
                             for v in &vars
                             {
                                 let s = v.name.iter().collect::<String>();
                                 if s.starts_with(&word)
                                 {
-                                    bank1.push(s)
+                                    bank.push(s)
                                 }
                             }
-                            let mut bank2 = Vec::new();
+                            let mut bank_temp = Vec::new();
                             for f in functions_with_args()
                             {
                                 if f.starts_with(&word)
-                                    && !bank1.iter().any(|b| {
+                                    && !bank.iter().any(|b| {
                                         b.contains('(')
                                             && b.split('(').next().unwrap()
                                                 == f.split('(').next().unwrap()
                                     })
                                 {
-                                    bank2.push(f.to_string())
+                                    bank_temp.push(f.to_string())
                                 }
                             }
-                            bank1.extend(bank2);
-                            bank1.sort();
-                            let mut var = false;
-                            if bank1.len() == 1
+                            bank.extend(bank_temp);
+                            let mut bank_temp = Vec::new();
+                            for f in options_list()
                             {
-                                let mut w = bank1[0].to_string();
+                                if f.starts_with(&word)
+                                    && !bank.iter().any(|b| {
+                                        b.contains('(')
+                                            && b.split('(').next().unwrap()
+                                                == f.split('(').next().unwrap()
+                                    })
+                                {
+                                    bank_temp.push(f.to_string())
+                                }
+                            }
+                            bank.extend(bank_temp);
+                            if options.units
+                            {
+                                let mut bank_temp = Vec::new();
+                                for f in units_list()
+                                {
+                                    if f.starts_with(&word)
+                                        && !bank.iter().any(|b| {
+                                            b.contains('(')
+                                                && b.split('(').next().unwrap()
+                                                    == f.split('(').next().unwrap()
+                                        })
+                                    {
+                                        bank_temp.push(f.to_string())
+                                    }
+                                }
+                                bank.extend(bank_temp);
+                            }
+                            bank.sort();
+                            let mut var = false;
+                            if bank.len() == 1
+                            {
+                                let mut w = bank[0].to_string();
                                 if w.contains('(')
                                 {
                                     w = w.split('(').next().unwrap().to_string();
@@ -1717,6 +1783,7 @@ fn main()
                                     firstslow = false;
                                     handle_err(
                                         "too slow, will print on enter",
+                                        &vars,
                                         &input,
                                         options,
                                         &colors,
@@ -1726,21 +1793,21 @@ fn main()
                                 }
                                 else
                                 {
-                                    clear(&input, start, end, options, &colors);
+                                    clear(&input, &vars, start, end, options, &colors);
                                 }
                                 if end - placement != 0
                                 {
                                     print!("\x1b[{}D", end - placement)
                                 }
                             }
-                            else if !bank1.is_empty()
+                            else if !bank.is_empty()
                             {
                                 let mut k = 0;
                                 let mut char = '\0';
                                 'upper: for n in
-                                    0..bank1.iter().fold(usize::MAX, |min, str| min.min(str.len()))
+                                    0..bank.iter().fold(usize::MAX, |min, str| min.min(str.len()))
                                 {
-                                    for b in &bank1
+                                    for b in &bank
                                     {
                                         let c = b.chars().nth(n).unwrap();
                                         if char == '\0'
@@ -1757,7 +1824,7 @@ fn main()
                                 }
                                 input.splice(
                                     placement..placement,
-                                    bank1[0][word.chars().count()..k].chars(),
+                                    bank[0][word.chars().count()..k].chars(),
                                 );
                                 placement += k - word.chars().count();
                                 end = start + get_terminal_dimensions().0
@@ -1783,20 +1850,20 @@ fn main()
                                 {
                                     lines[i] = input.clone().iter().collect::<String>();
                                 }
-                                clear(&input, start, end, options, &colors);
+                                clear(&input, &vars, start, end, options, &colors);
                                 if end - placement != 0
                                 {
                                     print!("\x1b[{}D", end - placement)
                                 }
                             }
-                            if !var && !bank1.is_empty()
+                            if !var && !bank.is_empty()
                             {
                                 let width = get_terminal_dimensions().0;
                                 let mut n = 1;
-                                let tab = bank1.iter().fold(0, |max, str| max.max(str.len())) + 3;
+                                let tab = bank.iter().fold(0, |max, str| max.max(str.len())) + 3;
                                 let mut len = 0;
                                 print!("\x1b[G\n\x1b[K");
-                                for b in bank1
+                                for b in bank
                                 {
                                     if len + tab > width
                                     {
@@ -1809,6 +1876,7 @@ fn main()
                                         "{}{}",
                                         to_output(
                                             &b.chars().collect::<Vec<char>>(),
+                                            &vars,
                                             options.color == Auto::True,
                                             &colors
                                         ),
@@ -1876,6 +1944,7 @@ fn main()
                             firstslow = false;
                             handle_err(
                                 "too slow, will print on enter",
+                                &vars,
                                 &input,
                                 options,
                                 &colors,
@@ -1885,7 +1954,7 @@ fn main()
                         }
                         else
                         {
-                            clearln(&input, start, end, options, &colors);
+                            clearln(&input, &vars, start, end, options, &colors);
                         }
                         if options.debug
                         {
@@ -1904,14 +1973,7 @@ fn main()
                 }
                 stdout.flush().unwrap();
             }
-            commands(
-                &mut options,
-                &colors,
-                &mut vars,
-                &lines,
-                &input,
-                &mut stdout,
-            );
+            commands(&mut options, &lines, &input, &mut stdout);
             if !varcheck
             {
                 print!(
