@@ -11,7 +11,7 @@ use crate::{
         clear, get_terminal_dimensions, handle_err, insert_last, no_col, no_col_len,
         parsed_to_string, prompt, to_output,
     },
-    options::{equal_to, silent_commands},
+    options::{equal_to, list_vars, silent_commands},
     parse::input_var,
     AngleType::{Degrees, Gradians, Radians},
     Colors, HowGraphing,
@@ -35,9 +35,93 @@ pub fn print_concurrent(
     let mut vars = vars;
     if unmodified_input.starts_with(&['#']) || unmodified_input.is_empty()
     {
-        clear(unmodified_input, start, end, options, &colors);
+        clear(unmodified_input, vars, start, end, options, &colors);
         return (0, HowGraphing::default(), false, false);
     }
+    if matches!(
+        unmodified_input.iter().collect::<String>().as_str(),
+        "vars" | "variables"
+    )
+    {
+        let list = list_vars(vars, &options, &colors);
+        let (width, height) = get_terminal_dimensions();
+        let n = no_col(&list, options.color == crate::Auto::True)
+            .iter()
+            .collect::<String>()
+            .split("\n")
+            .map(|a| a.len().div_ceil(width))
+            .sum();
+        return if n + 1 >= height
+        {
+            print!(
+                "\x1b[J\x1b[G\ntoo long, will print on enter\x1b[G\x1b[A\x1b[K{}{}{}",
+                prompt(options, &colors),
+                to_output(
+                    &unmodified_input[start..end],
+                    vars,
+                    options.color == crate::Auto::True,
+                    &colors
+                ),
+                if options.color == crate::Auto::True
+                {
+                    "\x1b[0m"
+                }
+                else
+                {
+                    ""
+                },
+            );
+            (0, HowGraphing::default(), true, false)
+        }
+        else
+        {
+            print!(
+                "\x1b[G\n\x1b[J{}\x1b[{}A\x1b[K{}{}{}",
+                list,
+                n + 1,
+                prompt(options, &colors),
+                to_output(
+                    &unmodified_input[start..end],
+                    vars,
+                    options.color == crate::Auto::True,
+                    &colors
+                ),
+                if options.color == crate::Auto::True
+                {
+                    "\x1b[0m"
+                }
+                else
+                {
+                    ""
+                }
+            );
+            (n, HowGraphing::default(), false, false)
+        };
+    }
+    if unmodified_input.iter().collect::<String>() == "version"
+    {
+        print!(
+            "\x1b[J\x1b[G\n{} {}\x1b[G\x1b[A\x1b[K{}{}{}",
+            env!("CARGO_PKG_NAME"),
+            env!("CARGO_PKG_VERSION"),
+            prompt(options, &colors),
+            to_output(
+                &unmodified_input[start..end],
+                vars,
+                options.color == crate::Auto::True,
+                &colors
+            ),
+            if options.color == crate::Auto::True
+            {
+                "\x1b[0m"
+            }
+            else
+            {
+                ""
+            },
+        );
+        return (1, HowGraphing::default(), false, false);
+    }
     let mut var;
     let mut unparsed = unmodified_input;
     {
@@ -66,7 +150,7 @@ pub fn print_concurrent(
                     {
                         if let Err(s) = set_commands_or_vars(&mut colors, &mut options, &mut var, s)
                         {
-                            handle_err(s, unmodified_input, options, &colors, start, end);
+                            handle_err(s, vars, unmodified_input, options, &colors, start, end);
                             return (1, HowGraphing::default(), false, false);
                         }
                     }
@@ -103,6 +187,7 @@ pub fn print_concurrent(
                 prompt(options, &colors),
                 to_output(
                     &unmodified_input[start..end],
+                    vars,
                     options.color == crate::Auto::True,
                     &colors
                 ),
@@ -132,6 +217,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -156,7 +242,7 @@ pub fn print_concurrent(
                         if !input.is_empty()
                         {
                             let mut input = input;
-                            let split = input.split(|c| c == ';');
+                            let split = input.split(';');
                             let count = split.clone().count();
                             if count != 1
                             {
@@ -184,6 +270,7 @@ pub fn print_concurrent(
                                         {
                                             handle_err(
                                                 s,
+                                                &vars,
                                                 unmodified_input,
                                                 options,
                                                 &colors,
@@ -258,6 +345,7 @@ pub fn print_concurrent(
                             prompt(options, &colors),
                             to_output(
                                 &unmodified_input[start..end],
+                                vars,
                                 options.color == crate::Auto::True,
                                 &colors
                             ),
@@ -289,6 +377,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -306,7 +395,7 @@ pub fn print_concurrent(
             }
             else
             {
-                clear(unmodified_input, start, end, options, &colors);
+                clear(unmodified_input, vars, start, end, options, &colors);
                 (0, HowGraphing::default(), false, false)
             };
         }
@@ -323,17 +412,18 @@ pub fn print_concurrent(
         Vec::new(),
         false,
         &mut Vec::new(),
+        None,
     )
     {
         Ok(f) => f,
         Err(s) =>
         {
-            handle_err(s, unmodified_input, options, &colors, start, end);
+            handle_err(s, vars, unmodified_input, options, &colors, start, end);
             return (1, HowGraphing::default(), false, false);
         }
     };
     {
-        if input.3
+        if input.3 && !unmodified_input.contains(&'#')
         {
             let n = unparsed.iter().position(|c| c == &'=').unwrap_or(0) + 1;
             let mut inputs = unparsed[n..].iter().collect::<String>();
@@ -376,6 +466,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -465,21 +556,26 @@ pub fn print_concurrent(
                     func,
                     false,
                     &mut Vec::new(),
+                    None,
                 );
                 if def
                 {
                     let out = match tinput
                     {
-                        Ok(n) if !n.0.is_empty() => parsed_to_string(n.0, n.1, &options, &colors),
+                        Ok(n) if !n.0.is_empty() =>
+                        {
+                            parsed_to_string(n.0, vars, n.1, &options, &colors)
+                        }
                         Err(s) =>
                         {
-                            handle_err(s, unmodified_input, options, &colors, start, end);
+                            handle_err(s, vars, unmodified_input, options, &colors, start, end);
                             return (1, HowGraphing::default(), false, false);
                         }
                         _ =>
                         {
                             handle_err(
                                 "equal sign on right side of definition",
+                                vars,
                                 unmodified_input,
                                 options,
                                 &colors,
@@ -491,7 +587,7 @@ pub fn print_concurrent(
                     };
                     if out.is_empty()
                     {
-                        clear(unmodified_input, start, end, options, &colors);
+                        clear(unmodified_input, vars, start, end, options, &colors);
                         return (0, HowGraphing::default(), false, true);
                     }
                     let (width, height) = get_terminal_dimensions();
@@ -520,7 +616,7 @@ pub fn print_concurrent(
                             print!(
                                 "\x1b[J\x1b[G\ntoo long, will print on enter\x1b[G\x1b[A\x1b[K{}{}{}",
                                 prompt(options, &colors),
-                                to_output(&unmodified_input[start..end], options.color==crate::Auto::True, &colors),
+                                to_output(&unmodified_input[start..end],vars, options.color==crate::Auto::True, &colors),
                                 if options.color==crate::Auto::Auto { "\x1b[0m" } else { "" },
                             );
                             (0, input.2, true, true)
@@ -542,6 +638,7 @@ pub fn print_concurrent(
                             prompt(options, &colors),
                             to_output(
                                 &unmodified_input[start..end],
+                                vars,
                                 options.color == crate::Auto::True,
                                 &colors
                             ),
@@ -565,13 +662,14 @@ pub fn print_concurrent(
                         Ok(f) if !f.0.is_empty() => f,
                         Err(s) =>
                         {
-                            handle_err(s, unmodified_input, options, &colors, start, end);
+                            handle_err(s, vars, unmodified_input, options, &colors, start, end);
                             return (1, HowGraphing::default(), false, false);
                         }
                         _ =>
                         {
                             handle_err(
                                 "equal sign on right side of definition",
+                                vars,
                                 unmodified_input,
                                 options,
                                 &colors,
@@ -585,10 +683,11 @@ pub fn print_concurrent(
             };
         }
     }
-    if input.2.graph
+    if input.2.graph || unmodified_input.contains(&'#')
     {
         return if unmodified_input.contains(&'#')
         {
+            input.2.graph = true;
             let mut out = String::new();
             {
                 let split = unmodified_input.iter().collect::<String>();
@@ -600,6 +699,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -624,7 +724,7 @@ pub fn print_concurrent(
                         if !input.is_empty()
                         {
                             let mut input = input;
-                            let split = input.split(|c| c == ';');
+                            let split = input.split(';');
                             let count = split.clone().count();
                             if count != 1
                             {
@@ -652,6 +752,7 @@ pub fn print_concurrent(
                                         {
                                             handle_err(
                                                 s,
+                                                &vars,
                                                 unmodified_input,
                                                 options,
                                                 &colors,
@@ -715,7 +816,7 @@ pub fn print_concurrent(
                 print!(
                     "\x1b[J\x1b[G\ntoo long, append '=' to see parsed input\x1b[G\x1b[A\x1b[K{}{}{}",
                     prompt(options, &colors),
-                    to_output(&unmodified_input[start..end], options.color==crate::Auto::True, &colors),
+                    to_output(&unmodified_input[start..end],vars, options.color==crate::Auto::True, &colors),
                     if options.color==crate::Auto::Auto { "\x1b[0m" } else { "" },
                 );
                 (1, input.2, true, false)
@@ -736,6 +837,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -768,7 +870,7 @@ pub fn print_concurrent(
                 print!(
                     "\x1b[J\x1b[G\ntoo long, append '=' to see parsed input\x1b[G\x1b[A\x1b[K{}{}{}",
                     prompt(options, &colors),
-                    to_output(&unmodified_input[start..end], options.color==crate::Auto::True, &colors),
+                    to_output(&unmodified_input[start..end],vars, options.color==crate::Auto::True, &colors),
                     if options.color==crate::Auto::Auto { "\x1b[0m" } else { "" },
                 );
                 (1, input.2, true, false)
@@ -789,6 +891,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -812,12 +915,12 @@ pub fn print_concurrent(
         {
             return if s == " "
             {
-                clear(unmodified_input, start, end, options, &colors);
+                clear(unmodified_input, vars, start, end, options, &colors);
                 (0, HowGraphing::default(), false, false)
             }
             else
             {
-                handle_err(s, unmodified_input, options, &colors, start, end);
+                handle_err(s, vars, unmodified_input, options, &colors, start, end);
                 (1, HowGraphing::default(), false, false)
             }
         }
@@ -1017,6 +1120,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -1068,6 +1172,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -1089,6 +1194,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -1306,6 +1412,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -1330,6 +1437,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -1657,6 +1765,7 @@ pub fn print_concurrent(
                         prompt(options, &colors),
                         to_output(
                             &unmodified_input[start..end],
+                            vars,
                             options.color == crate::Auto::True,
                             &colors
                         ),
@@ -1684,6 +1793,7 @@ pub fn print_concurrent(
                     prompt(options, &colors),
                     to_output(
                         &unmodified_input[start..end],
+                        vars,
                         options.color == crate::Auto::True,
                         &colors
                     ),
@@ -1722,7 +1832,15 @@ pub fn print_concurrent(
                 frac += num;
             }
         }
-        _ => handle_err("str err", unmodified_input, options, &colors, start, end),
+        _ => handle_err(
+            "str err",
+            vars,
+            unmodified_input,
+            options,
+            &colors,
+            start,
+            end,
+        ),
     }
     (frac + 1, HowGraphing::default(), long, var)
 }
@@ -1967,7 +2085,7 @@ pub fn get_output(
                                 ""
                             }
                     }
-                    else if n.contains('e')
+                    else if n.contains('e') && options.base.1 < 16
                     {
                         n.replace("e0", "").replace('e', &notate(options, colors))
                             + if options.color == crate::Auto::True
@@ -2009,7 +2127,7 @@ pub fn get_output(
                                 ""
                             }
                     }
-                    else if n.contains('e')
+                    else if n.contains('e') && options.base.1 < 16
                     {
                         n.replace("e0", "").replace('e', &notate(options, colors))
                             + if options.color == crate::Auto::True
@@ -2434,6 +2552,10 @@ fn to_string(num: &Float, options: Options, imag: bool, radix: i32) -> String
     {
         neg = ""
     }
+    if zeros.len() == decimals
+    {
+        zeros.pop();
+    }
     if decimals == 0
     {
         if zeros.is_empty()
@@ -2685,4 +2807,4 @@ fn notate(options: Options, colors: &Colors) -> String
             Normal => "",
         },
     )
-}
\ No newline at end of file
+}
